@@ -16,7 +16,7 @@ global json_file_utc_run_datetime
 global qualys_headers_multi_proc_dict
 
 
-def asset_inventory_extract(asset_last_updated, last_seen_assetid, utc_datetime, batch_number, proc_dict):
+def asset_inventory_extract(asset_last_updated, last_seen_assetid, utc_datetime, batch_number, proc_dict, cred_dict):
     global json_file
     global url
     global multi_proc_host_ids
@@ -27,8 +27,9 @@ def asset_inventory_extract(asset_last_updated, last_seen_assetid, utc_datetime,
     qualys_headers_multi_proc_dict = proc_dict
     json_file_utc_run_datetime = utc_datetime
     multi_proc_batch_number = batch_number
-    cred_dict = etld_lib_credentials.get_cred()
-    bearer = etld_lib_credentials.get_bearer(update_bearer=False)
+    cred_dict = etld_lib_credentials.get_cred(cred_dict)
+    cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=False, cred=cred_dict)
+    bearer = cred_dict['bearer']
     url = f"https://{cred_dict['gateway_fqdn_server']}/rest/2.0/search/am/asset"
     # /rest/2.0/search/am/asset?assetLastUpdated=2021-06-01T00:00:00Z&lastSeenAssetId=0
     if isinstance(etld_lib_config.asset_inventory_multi_proc_batch_size, str):
@@ -74,8 +75,10 @@ def asset_inventory_extract(asset_last_updated, last_seen_assetid, utc_datetime,
         multi_proc_batch_number=multi_proc_batch_number,
         extract_validation_type='json')
 
+    return cred_dict
 
-def asset_inventory_extract_count(asset_last_updated, last_seen_assetid, utc_datetime, batch_number, proc_dict):
+
+def asset_inventory_extract_count(asset_last_updated, last_seen_assetid, utc_datetime, batch_number, proc_dict, cred_dict):
     global json_file
     global url
     global multi_proc_host_ids
@@ -86,28 +89,13 @@ def asset_inventory_extract_count(asset_last_updated, last_seen_assetid, utc_dat
     qualys_headers_multi_proc_dict = proc_dict
     json_file_utc_run_datetime = utc_datetime
     multi_proc_batch_number = batch_number
-    cred_dict = etld_lib_credentials.get_cred()
-    bearer = etld_lib_credentials.get_bearer(update_bearer=False)
-    # rest/2.0/count/am/asset
+    cred_dict = etld_lib_credentials.get_cred(cred_dict)
+    cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=False, cred=cred_dict)
+    bearer = cred_dict['bearer']
     url = f"https://{cred_dict['gateway_fqdn_server']}/rest/2.0/count/am/asset"
-    # /rest/2.0/search/am/asset?assetLastUpdated=2021-06-01T00:00:00Z&lastSeenAssetId=0
-    if isinstance(etld_lib_config.asset_inventory_multi_proc_batch_size, str):
-        page_size = 300
-    elif etld_lib_config.asset_inventory_multi_proc_batch_size > 300:
-        page_size = 300
-    elif etld_lib_config.asset_inventory_multi_proc_batch_size < 1:
-        page_size = 300
-    else:
-        page_size = etld_lib_config.asset_inventory_multi_proc_batch_size
-
     url = f"{url}?assetLastUpdated={asset_last_updated}&lastSeenAssetId={last_seen_assetid}"
-
-    # payload = {'assetLastUpdated': asset_last_updated,
-    #            'lastSeenAssetId': last_seen_assetid}
-
     headers = {'X-Requested-With': 'qualysetl', 'Authorization': bearer, 'Content-Type': 'application/json'}
 
-#    print_payload = payload.copy()
     etld_lib_functions.logger.info(f"api call     - {url}")
 
     json_file_prefix = "asset_inventory_extract_count"
@@ -135,6 +123,7 @@ def asset_inventory_extract_count(asset_last_updated, last_seen_assetid, utc_dat
         extract_validation_type='json')
 
     asset_inventory_log_count()
+    return cred_dict
 
 
 def asset_inventory_log_count():
