@@ -2,8 +2,6 @@ import shelve
 import xmltodict
 import time
 from pathlib import Path
-import os
-import oschmod
 
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
@@ -15,6 +13,7 @@ global xml_dir
 global xml_dir_search_glob
 global xml_file_list
 global callback_item
+global counter_obj
 
 
 def transform_xml_item_to_shelve(_, item):
@@ -24,6 +23,7 @@ def transform_xml_item_to_shelve(_, item):
     global shelve_file
     global xml_dir_search_glob
     global callback_item
+    global counter_obj
 
     if len(_) > 2 and "HOST" != _[3][0]:
         return True
@@ -33,7 +33,8 @@ def transform_xml_item_to_shelve(_, item):
     for i in range(max_retries):
         try:
             shelve_database[ID] = item
-            count_items_added_to_shelve = count_items_added_to_shelve + 1
+            count_items_added_to_shelve += 1
+            counter_obj.display_counter_to_log()
         except Exception as e:
             time.sleep(1)
             etld_lib_functions.logger.warning(
@@ -62,6 +63,7 @@ def host_list_detection_shelve():
     global xml_dir_search_glob
     global xml_file_list
     global callback_item
+    global counter_obj
 
     if Path(shelve_file).is_file():
         Path(shelve_file).unlink()  # Remove old host list detection shelve
@@ -85,8 +87,9 @@ def end_msg_host_list_detection_shelve():
     global xml_dir
     global xml_file_list
 
+    counter_obj.display_final_counter_to_log()
     etld_lib_functions.logger.info(
-        f"count host ids added to shelve: {count_items_added_to_shelve:,} for {str(shelve_file)}")
+        f"total count host list detection records written to shelve: {count_items_added_to_shelve:,} for {str(shelve_file)}")
     for xml_file in xml_file_list:
         etld_lib_functions.log_file_info(xml_file, 'in')
     etld_lib_functions.log_dbm_info(shelve_file)
@@ -113,12 +116,18 @@ def setup_shelve_vars():
     global shelve_database
     global xml_dir_search_glob
     global callback_item
+    global counter_obj
     count_items_added_to_shelve = 0
     callback_item = transform_xml_item_to_shelve
     shelve_file = etld_lib_config.host_list_detection_shelve_file
     xml_dir = etld_lib_config.host_list_detection_xml_dir
     shelve_database = etld_lib_config.host_list_detection_shelve_file
     xml_dir_search_glob = 'host_list_detection*.xml'
+    counter_obj = \
+        etld_lib_functions.DisplayCounterToLog(display_counter_at=10000,
+                                               logger_func=etld_lib_functions.logger.info,
+                                               display_counter_log_message=
+                                               "count host list detection records written to shelve")
 
 
 if __name__ == "__main__":
