@@ -310,7 +310,8 @@ def qualys_gateway_login():
     try:
         if Path(bearer_file).is_file():
             Path(bearer_file).unlink()
-        response = requests.request("POST", url, headers=headers, data=payload)
+        response = requests.request("POST", url, headers=headers, data=payload,
+                                    verify=etld_lib_config.requests_module_tls_verify_status)
         http_return_code = response.status_code
         if response.status_code == 201:
             bearer = f"Bearer {response.text}"
@@ -388,7 +389,8 @@ def qualys_gateway_login_store_in_env(cred_dict={}):
                'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
 
     try:
-        response = requests.request("POST", url, headers=headers, data=payload)
+        response = requests.request("POST", url, headers=headers, data=payload,
+                                    verify=etld_lib_config.requests_module_tls_verify_status)
         http_return_code = response.status_code
         if response.status_code == 201:
             with open(bearer_file, 'w', encoding='utf-8') as bearerfile:
@@ -437,7 +439,8 @@ def qualys_login():
                'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
 
     try:
-        response = requests.request("POST", url, headers=headers, data=payload)
+        response = requests.request("POST", url, headers=headers, data=payload,
+                                    verify=etld_lib_config.requests_module_tls_verify_status)
         http_return_code = response.status_code
         if response.status_code == 200:
             cookie_dict = response.cookies.get_dict()
@@ -478,7 +481,8 @@ def qualys_logout():
                    'Content-Type': 'application/x-www-form-urlencoded', 'Cookie': get_cookie(update_cookie=False),
                    'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
         try:
-            response = requests.request("POST", url, headers=headers, data=payload)
+            response = requests.request("POST", url, headers=headers, data=payload,
+                                        verify=etld_lib_config.requests_module_tls_verify_status)
             if response.status_code == 200:
                 etld_lib_functions.logger.info(f"LOGOUT - Qualys Logout Success with user: {cred_dict['username']}")
             else:
