@@ -54,10 +54,14 @@ def create_table(table_name, csv_columns, sqlite_file, key=False, csv_column_typ
         exit(1)
 
 
-def bulk_insert_csv_file(table_name, csv_file_name, csv_columns, sqlite_file, message=""):
+def bulk_insert_csv_file(table_name, csv_file_name, csv_columns, sqlite_file, message="",
+                         display_progress_counter_at_this_number=10000):
     global count_rows_added_to_table
-    count_rows_added_to_table_display_progress = 0
     csv.field_size_limit(sys.maxsize)
+    sqlite_rows_written = \
+        etld_lib_functions.DisplayCounterToLog(display_counter_at=display_progress_counter_at_this_number,
+                                               logger_func=etld_lib_functions.logger.info,
+                                               display_counter_log_message=f"count {table_name} sqlite rows written")
     # etld_lib_functions.logger.info(f"csv.field_size_limit(sys.maxsize): {str(sys.maxsize)}")
     try:
         values_var = ""
@@ -80,16 +84,16 @@ def bulk_insert_csv_file(table_name, csv_file_name, csv_columns, sqlite_file, me
                     cursor_obj.executemany(f"INSERT INTO {table_name} VALUES({values_var})", csv_row_list)
                     conn.commit()
                     csv_row_list = []
+                sqlite_rows_written.display_counter_to_log()
                 count_rows_added_to_table += 1
-                count_rows_added_to_table_display_progress += 1
-                if count_rows_added_to_table_display_progress > 9999:
-                    etld_lib_functions.logger.info(f"sqlite {message} rows written: {count_rows_added_to_table}")
-                    count_rows_added_to_table_display_progress = 0
 
             if len(csv_row_list) > 0:
                 cursor_obj.executemany(f"INSERT INTO {table_name} VALUES({values_var})", csv_row_list)
                 conn.commit()
                 csv_row_list = []
+
+        sqlite_rows_written.display_final_counter_to_log()
+
     except Exception as e:
         etld_lib_functions.logger.error(f"Error creating table from: {csv_file_name}, please retry after fixing error")
         etld_lib_functions.logger.error(f"Row Number: {count_rows_added_to_table}, please retry after fixing error")
