@@ -10,6 +10,7 @@ import time
 import getpass
 import json
 from pathlib import Path
+import qualys_etl
 import qualys_etl.etld_lib.etld_lib_functions as etld_lib_functions
 import qualys_etl.etld_lib.etld_lib_config as etld_lib_config
 import qualys_etl.etld_lib.etld_lib_credentials as etld_lib_credentials
@@ -394,15 +395,13 @@ def help_message(notes):
         
     usage: qetl_manage_user [-h] -u qetl_USER_HOME_DIR [-e execute etl module] [-c] [-t] [-d] [-r] [-l]
     
-    Setup and execute etl module for your qualys qetl users.  
+    Command to Extract, Transform and Load Qualys Data into various forms ( CSV, JSON, SQLITE3 DATABASE )
     
     optional arguments:
       -h, --help                show this help message and exit
       -u Home Directory Path, --qetl_user_home_dir Home directory Path
-                                   Include prefix opt/qetl/users/[user dir] 
-                                   Examples:
-                                   1) /home/dgregory/opt/qetl/users/q_username 
-                                   2) /opt/qetl/users/q_username
+                                   Example:
+                                   - /opt/qetl/users/q_username
       -e etl module name,     --execute_etl_module module name
                                   Ex.  -e etl_knowledgebase or -e etl_host_list or -e etl_host_list_detection -e etl_asset_inventory
       -d YYMMDDThh:mm:ssZ,    --datetime        YYYY-MM-DDThh:mm:ssZ UTC. Get All Data On or After Date. 
@@ -410,12 +409,15 @@ def help_message(notes):
       -c, --credentials       update qualys api user credentials: qualys username, password or api_fqdn_server
       -t, --test              test qualys credentials
       -l, --logs              detailed logs sent to stdout for testing qualys credentials
+      -v, --version           Help and QualysETL version information.
       -r, --report            brief report of the users directory structure.
       -p, --prompt-credentials prompt user for credentials, also accepts stdin with credentials piped to program.
       -m, --memory-credentials get credentials from environment: q_username, q_password, q_api_fqdn_server
       -s, --stdin-credentials  send credentials in json to stdin. 
                                Example:
-                               {"q_username": "your userid", "q_password": "your password", "q_api_fqdn_server": "api fqdn", "q_gateway_fqdn_server": "gateway api fqdn"}
+                               {{"q_username": "your userid", "q_password": "your password", "q_api_fqdn_server": "api fqdn", "q_gateway_fqdn_server": "gateway api fqdn"}}
+                               
+      QualysETL Version: {qualys_etl.__version__}
     '''
     print(f"{help_mess}")
 
@@ -427,9 +429,6 @@ def test_command_line_arguments():
     if results.qetl_user_home_dir is None:
         help_message(f"Please enter -u [ your /opt/qetl/users/ user home directory path ]\n\n"
                      f"    Note: /opt/qetl/users/newuser is the root directory for your qetl userhome directory,\n" 
-                     f"           enter a new path including the opt/qetl/users/newuser \n"
-                     f"           in the path you have authorization to write to.\n"
-                     f"           the prefix to your user directory opt/qetl/users is required.\n"
                      f"    Example:\n"
                      f"             qetl_manage_user -u /opt/qetl/users/[your_user_name]\n"
                      f" ")
@@ -463,14 +462,14 @@ def test_command_line_arguments():
 
 def get_command_line_arguments(args=None):
     global command_line_arguments
-    parser = argparse.ArgumentParser(description='Setup and execute etl for your qualys qetl users.')
+    parser = argparse.ArgumentParser(description='Command to Extract, Transform and Load Qualys Data into various forms ( CSV, JSON, SQLITE3 DATABASE )')
     parser.add_argument('-u', '--qetl_user_home_dir', default=None, help="Please enter -u option")
     parser.add_argument('-e', '--execute_etl_module', default=None,
                         help='Execute etl_knowledgebase, etl_host_list, etl_host_list_detection, etl_asset_inventory')
     parser.add_argument('-d', '--datetime', default=None,
                         help='YYYY-MM-DDThh:mm:ssZ UTC. Get All Data On or After Date.  Ex. 1970-01-01T00:00:00Z acts as flag to obtain all data.')
     parser.add_argument('-c', '--credentials', default=None, action="store_true",
-                        help='update qualys api user credentials stored on disk: qualys uername, password or api_fqdn_server')
+                        help='update qualys api user credentials stored on disk: qualys username, password or api_fqdn_server')
     parser.add_argument('-t', '--test', default=None, action="store_true", help='test qualys credentials')
     parser.add_argument('-l', '--logs', default=None, action="store_true", help='detailed logs sent to stdout for test qualys credentials')
     parser.add_argument('-p', '--prompt_credentials', default=None, action="store_true", help='prompt user for credentials')
@@ -478,8 +477,8 @@ def get_command_line_arguments(args=None):
                         help='read stdin credentials json {"q_username":"your userid", "q_password":"your password", "q_api_fqdn_server":"api fqdn", "q_gateway_fqdn_server":"gateway api fqdn"}')
     parser.add_argument('-m', '--memory_credentials', default=None, action="store_true",
                         help='Get credentials from environment variables in memory: q_username, q_password, q_api_fqdn_server, and optionally add q_gateway_fqdn_server. Ex. export q_username=myuser')
-    parser.add_argument('-r', '--report', default=None, action="store_true",
-                        help='Brief report of the users directory structure.')
+    parser.add_argument('-v', '--version', default=None, action="store_true", help='Help and QualysETL Version')
+    parser.add_argument('-r', '--report', default=None, action="store_true", help='Brief report of the users directory structure.')
     command_line_arguments = parser.parse_args(args)
 
 
@@ -536,6 +535,7 @@ def main():
     get_command_line_arguments(sys.argv[1:])
     test_command_line_arguments()
     setup_qetl_user_home_dir_environment()
+
     if if_stdin_credentials():
         pass
     elif if_prompt_credentials():
